Learn R Programming

rhoneycomb (version 2.3.4)

return_ungrouped: This function returns only the ungrouped replicated selection designs.

Description

It calls the check for R function and keeps only the Ungrouped selection designs.

Usage

return_ungrouped(R_gen)

Value

A dataframe.

Arguments

R_gen

A single number or vector containing the replicated selection designs for testing.