powered by
It calls the check for R function and keeps only the Ungrouped selection designs.
return_ungrouped(R_gen)
A dataframe.
A single number or vector containing the replicated selection designs for testing.